     <?php
// 查询IP地址信息的函数
function getIpInfo($ip) {
    $apiUrl = "http://ip-api.com/json/{$ip}";
    $response = file_get_contents($apiUrl);
    return json_decode($response, true);
}

// 替换为使用WHOIS API的查询函数
function getWhoisInfo($query) {
    $apiKey = "at_1XoLbhNyDCQlo8Eadl39AGxRCgOMY"; // 替换为你的WhoisXMLAPI密钥
    $apiUrl = "https://www.whoisxmlapi.com/whoisserver/WhoisService?apiKey={$apiKey}&domainName={$query}&outputFormat=JSON";

    $response = @file_get_contents($apiUrl);

    if ($response === false) {
        return "无法获取WHOIS信息，请检查输入或稍后再试。";
    }

    $whoisData = json_decode($response, true);

    if (isset($whoisData['ErrorMessage'])) {
        return "错误：" . htmlspecialchars($whoisData['ErrorMessage']['msg']);
    }

    return htmlspecialchars($whoisData['WhoisRecord']['rawText']);
}

// 处理用户提交
$ip = $_POST['ip'] ?? '';
$whoisQuery = $_POST['whois_query'] ?? '';
$ipInfo = $whoisInfo = null;

if (filter_var($ip, FILTER_VALIDATE_IP)) {
    $ipInfo = getIpInfo($ip);
}

if (!empty($whoisQuery)) {
    $whoisInfo = getWhoisInfo($whoisQuery);
}
?>

<!DOCTYPE html>
<html lang="zh-CN">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>IP 和 WHOIS 查询工具</title>
    <link rel="icon" href="favicon.ico" type="image/x-icon">
        <!-- Google Fonts -->
    <link href="https://fonts.googleapis.com/css2?family=Open+Sans:wght@400;600;700&display=swap" rel="stylesheet">
    <!-- Font-awesome -->
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/5.15.3/css/all.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/flag-icon-css/3.5.0/css/flag-icon.min.css">
    <link rel="stylesheet" href="css/style.css">
</head>
<body>
    <header>
        <div class="header-container">
            <a href="/" class="logo-link">
        <img src="/images/logo.png" alt="Logo" class="logo">
    </a>
       <h1 class="header-title">IP 和 WHOIS 查询工具</h1>
        <!-- 顶部IP地址和天气显示 -->
        <div class="header-info">
            <p id="ip-info">IP: 获取中... <img id="country-flag" src="" alt="国旗"></p>
            <p id="weather-info">天气: 获取中...</p>
        </div>
    </div>
        <nav class="navbar">
            <a href="/">首页</a>
            <a href="/about">关于</a>
            <a href="/help">帮助</a>
        </nav>
    </header>
    <div class="container">
        <h2>查询工具</h2>
        <!-- IP查询表单 -->
        <form method="post" action="">
            <div class="form-group">
                <label for="ip">IP地址查询：</label>
                <input type="text" id="ip" name="ip" value="<?= htmlspecialchars($ip) ?>" placeholder="请输入IP地址">
            </div>
            <button type="submit">查询IP信息</button>
        </form>

        <?php if ($ipInfo): ?>
            <div class="result">
                <h3>IP信息：</h3>
                <ul>
                    <li>IP地址：<?= htmlspecialchars($ipInfo['query']) ?></li>
                    <li>国家：<?= htmlspecialchars($ipInfo['country']) ?></li>
                    <li>地区：<?= htmlspecialchars($ipInfo['regionName']) ?></li>
                    <li>城市：<?= htmlspecialchars($ipInfo['city']) ?></li>
                    <li>ISP：<?= htmlspecialchars($ipInfo['isp']) ?></li>
                </ul>
            </div>
        <?php elseif ($ip): ?>
            <div class="result">
                <p>无法获取IP信息，请检查输入。</p>
            </div>
        <?php endif; ?>

        <!-- WHOIS查询表单 -->
        <form method="post" action="">
            <div class="form-group">
                <label for="whois_query">WHOIS查询：</label>
                <input type="text" id="whois_query" name="whois_query" value="<?= htmlspecialchars($whoisQuery) ?>" placeholder="请输入IP或域名">
            </div>
            <button type="submit">查询WHOIS信息</button>
        </form>

        <?php if ($whoisInfo): ?>
            <div class="result">
                <h3>WHOIS信息：</h3>
                <pre><?= $whoisInfo ?></pre>
            </div>
        <?php elseif ($whoisQuery): ?>
            <div class="result">
                <p>无法获取WHOIS信息，请检查输入。</p>
            </div>
        <?php endif; ?>
    </div>
    <footer>
        &copy; 2024 IP 和 WHOIS 查询工具 | 版权所有
    </footer>
    <script src="/js/ip-weather.js"></script>
</body>
</html>
