
       function fetchIpAndWeather() {
    try {
        // 使用 ipinfo.io 获取 IP 地址和位置
        const ipResponse = await fetch('https://ipinfo.io/json?token=58004f869449fc'); // 替换为你的 API 密钥
        if (!ipResponse.ok) throw new Error('IP 地址获取失败');
        
        const ipData = await ipResponse.json();
        const ip = ipData.ip;
        const city = ipData.city;
        const region = ipData.region;
        const country = ipData.country;
        const countryCode = ipData.country.toLowerCase();

        // 使用 Flag Icons 类来显示国旗
        const flagClass = `flag-icon flag-icon-${countryCode}`;
        document.getElementById('ip-info').innerHTML = `IP: ${ip} (${city}, ${region}, ${country}) <i class="${flagClass}"></i>`;

        const [latitude, longitude] = ipData.loc.split(',');

        // 获取天气
        const weatherApiKey = '72975f4e3fc84f9ba68160451240111'; // 替换为你从 WeatherAPI.com 获取的 API 密钥
        const weatherResponse = await fetch(`https://api.weatherapi.com/v1/current.json?key=${weatherApiKey}&q=${latitude},${longitude}`);
        if (!weatherResponse.ok) throw new Error('天气获取失败');
        
        const weatherData = await weatherResponse.json();
        const temperature = weatherData.current.temp_c; // 获取摄氏温度
        const weatherDescription = weatherData.current.condition.text;
        const weatherIcon = weatherData.current.condition.icon;

        // 更新天气信息
        document.getElementById('weather-info').innerHTML = `天气: ${city}, ${country} - ${temperature}°C (${weatherDescription}) <img src="https:${weatherIcon}" alt="${weatherDescription}" style="width: 16px; vertical-align:middle;">`;
    } catch (error) {
        // 捕获错误并显示
        console.error("Error:", error.message);
        document.getElementById('ip-info').textContent = 'IP: 获取失败';
        document.getElementById('weather-info').textContent = '天气: 获取失败';
    }
}

// 调用函数以获取数据
fetchIpAndWeather();

// 更新当前时间和日期
function updateTimeAndDate() {
    const currentDate = new Date();
    
    // 格式化时间和日期
    const hours = String(currentDate.getHours()).padStart(2, '0');
    const minutes = String(currentDate.getMinutes()).padStart(2, '0');
    const seconds = String(currentDate.getSeconds()).padStart(2, '0');
    const timeString = `${hours}:${minutes}:${seconds}`;
    
    const dateString = currentDate.toLocaleDateString(); // 当前日期 (格式: YYYY/MM/DD)

    // 更新页面上的时间和日期
    document.getElementById('current-time').textContent = timeString;
    document.getElementById('current-date').textContent = dateString;
}

// 每秒更新一次时间
setInterval(updateTimeAndDate, 1000);
updateTimeAndDate(); // 页面加载时立即更新一次时间和日期

// 每日一句名言（你可以从 API 获取）
const quotes = [
            "成功不是终点，失败也不是终结，最重要的是继续前进。 —— 温斯顿·丘吉尔",
            "不管你觉得自己多么强大，总有一天你会觉得迷茫，放下那些包袱。 —— 三毛",
            "你不能左右风的方向，但你可以调整帆的角度。 —— 乔·吉布森",
            "行动是治愈恐惧的良药，而等待只是恐惧的温床。 —— 戴尔·卡耐基",
            "只有在自己真正经历过艰难时刻的人，才会懂得幸福的意义。 —— 乔治·乔丹",
            "成功并不是拥有更多的财富，而是能够拥有一颗平静的心。 —— 爱默生",
            "勇敢并不是不感到恐惧，而是带着恐惧前行。 —— 纳尔逊·曼德拉",
            "为他人着想，才是生活的最高境界。 —— 林肯",
            "人可以被毁灭，但不能被打败。 —— 海明威",
            "无论何时，无论何地，心中要有光。 —— 海明威",
            "未来是属于那些相信自己梦想之美丽的人。 —— 埃莉诺·罗斯福",
            "生活中没有什么比努力更能打破沉寂的了。 —— 蒋勋",
            "你永远无法预见生命中最美好的部分，因为它们都在不经意间发生。 —— 丘吉尔",
            "智慧不是记住一切，而是能在合适的时机做出合适的选择。 —— 达尔文",
            "努力的意义不仅是为了今天的生活，而是为了明天能更好地生活。 —— 理查德·布兰森",
            "人若有志，万事可成；人若无志，万事皆空。 —— 孔子",
            "知识可以改变命运，但态度决定一切。 —— 威尔·罗杰斯",
            "我们的生命，就是为自己选择的那条路所赋予的意义。 —— 甘地",
            "生命中最伟大的事情不是我们所拥有的，而是我们所付出的。 —— 奥斯卡·王尔德",
            "任何一件事情，一旦你开始做，心里就已经充满了信心。 —— 斯坦福大学",
            "心中有阳光，生活才能温暖；心中有理想，生活才会闪亮。 —— 玛丽·凯·阿什",
            "每一段旅行都会让我们变得更好，也会让我们理解一些已经失去的东西。 —— 谷歌",
            "与其说是一个人被人生打败，不如说是人生没打败他。 —— 威尔·史密斯",
            "不要为了结果而做事，要为了过程而做事。 —— 张爱玲",
            "不畏将来，不念过去，活在当下。 —— 苏轼",
            "生活不仅仅是生存，更是享受。 —— 海伦·凯勒",
            "没有什么比奋斗更能改变命运。 —— 罗曼·罗兰",
            "我们不仅要赢得生活，还要享受生活。 —— 巴尔扎克",
            "梦想不是空想，而是行动。 —— 马克·吐温",
            "笑着面对挑战，它会告诉你，你是多么的强大。 —— 泰戈尔",
            "想要成功，就要保持好奇心和探索精神。 —— 爱因斯坦",
            "人生的目标是不断进步，而不是停滞不前。 —— 陈景润",
            "一个人真正的高贵，是在面对困境时的从容。 —— 丘吉尔",
            "无论怎样的现实生活，都无法阻止我们向梦想迈进。 —— 乔布斯",
            "每一个不曾起舞的日子，都是对生命的辜负。 —— 尼采",
            "有目标的人生才有意义，目的并非得到，而是成长。 —— 比尔·盖茨",
            "你能做的最好的事，就是对自己最真实。 —— 奥黛丽·赫本",
            "今天的行动，决定明天的风景。 —— 王石",
            "成功就是从失败到失败，也依然不丧失热情。 —— 温斯顿·丘吉尔",
            "你所遇到的每一位陌生人，都有可能改变你的一生。 —— 李嘉诚",
            "人的一生没有什么比追求真理更为重要。 —— 赫尔曼·黑塞",
            "有爱的人生才有意义。 —— 爱默生",
            "让每一天成为你的一次新生。 —— 德雷福斯",
            "机会总是留给有准备的人。 —— 爱迪·里斯",
            "你可以永远不做一个人，但你不能永远做一个失败者。 —— 李开复",
            "让心静下来，你会发现世界更宽广。 —— 史蒂夫·乔布斯",
            "活得更加真实，是自由的真正意义。 —— 艾默生",
            "你可以坚持很久，但是不要害怕失败。 —— 沃伦·巴菲特",
            "只有不断地追求目标，才能获得真正的自由。 —— 莱特",
            "成功的最大秘诀就是，始终保持不懈的努力。 —— 达·芬奇"
];

// 随机选择每日一句
function displayQuoteOfTheDay() {
    const randomQuote = quotes[Math.floor(Math.random() * quotes.length)];
    document.getElementById('quote-of-the-day').textContent = randomQuote;
}

// 初始化时显示每日一句
displayQuoteOfTheDay();
        // 获取当前日期
        const currentDate = new Date();
        const year = currentDate.getFullYear();
        const month = String(currentDate.getMonth() + 1).padStart(2, '0');
        const day = String(currentDate.getDate()).padStart(2, '0');
        const dateString = `${year}-${month}-${day}`;